# -*- coding:utf-8 -*-
# @Time     :2023/3/1 12:27
# @Author   :CHNJX
# @File     :test.py
# @Desc     :
import os
from urllib.parse import urlparse
import os


ls = os.listdir(r'G:\pythonProject\service-driver\api_object')


aa = {'s'}
aa.add('s')
print(aa)